<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk">
<context>
    <name></name>
    <message>
        <source>Delete</source>
        <translation type="vanished">Вилучити</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation type="vanished">На весь екран</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation type="vanished">Показ слайдів</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="vanished">Експортувати</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="vanished">Копіювати</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="vanished">Додати до вибраних</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation type="vanished">Обертати за годинниковою стрілкою</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation type="vanished">Обертати проти годинникової стрілки</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation type="vanished">Встановити зображенням тла</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation type="vanished">Показати у менеджері файлів</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation type="vanished">Дані щодо фотографії</translation>
    </message>
    <message>
        <source>Video info</source>
        <translation type="vanished">Дані щодо відео</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation type="vanished">Відновити</translation>
    </message>
</context>
<context>
    <name>AlbumCreateDialog</name>
    <message>
        <source>Unnamed</source>
        <translation>Без назви</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>Create</source>
        <translation>Створити</translation>
    </message>
    <message>
        <source>New Album</source>
        <translation>Новий альбом</translation>
    </message>
</context>
<context>
    <name>AlbumDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Вилучити</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this album?</source>
        <translation>Ви справді хочете вилучити цей альбом?</translation>
    </message>
</context>
<context>
    <name>AlbumLeftTabItem</name>
    <message>
        <source>Trash</source>
        <translation>Смітник</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Вибрані</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Імпортувати</translation>
    </message>
</context>
<context>
    <name>AlbumView</name>
    <message>
        <source>Trash</source>
        <translation>Смітник</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Вибрані</translation>
    </message>
    <message>
        <source>Or drag photos here</source>
        <translation>Або перетягніть сюди фотографії</translation>
    </message>
    <message>
        <source>Import All</source>
        <translation>Імпортувати все</translation>
    </message>
    <message>
        <source>Import to:</source>
        <translation>Імпортувати до:</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Імпортувати</translation>
    </message>
    <message>
        <source>System Disk</source>
        <translation>Системний диск</translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation>Галерея</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>Диск зайнято — зараз його не можна від&apos;єднувати</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Гаразд</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Новий альбом</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ігнорувати</translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation>Завантаження…</translation>
    </message>
    <message>
        <source>The files will be permanently deleted after the days shown on them</source>
        <translation>Кількість днів, за яку файли буде остаточно вилучено, показано на мініатюрах</translation>
    </message>
    <message>
        <source>Image classification</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <source>Album</source>
        <translation>Альбом</translation>
    </message>
</context>
<context>
    <name>CExportImageDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Замінити</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Експортувати</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Зображення</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Документи</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Завантаження</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Стільниця</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Відео</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Музика</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Назва:</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation>Зберегти у:</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Формат:</translation>
    </message>
    <message>
        <source>Quality:</source>
        <translation>Якість:</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Зберегти</translation>
    </message>
    <message>
        <source>gif</source>
        <translation>gif</translation>
    </message>
    <message>
        <source>Select other directories</source>
        <translation>Виберіть інші каталоги</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Гаразд</translation>
    </message>
    <message>
        <source>File name cannot be empty</source>
        <translation>Назва файла не може бути порожньою</translation>
    </message>
    <message>
        <source>already exists. Do you want to replace it?</source>
        <translation>вже існує. Хочете замінити його?</translation>
    </message>
</context>
<context>
    <name>DBManager</name>
    <message>
        <source>Screen Capture</source>
        <translation>Захолення з екрана</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Камера</translation>
    </message>
    <message>
        <source>Draw</source>
        <translation>Малювання</translation>
    </message>
    <message>
        <source>(copy)</source>
        <translation>(копія)</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Drive</source>
        <translation>Диск %1</translation>
    </message>
    <message>
        <source>Blank %1 Disc</source>
        <translation>Порожній диск %1</translation>
    </message>
    <message>
        <source>%1 Encrypted</source>
        <translation>Зашифрований %1</translation>
    </message>
    <message>
        <source>%1 Volume</source>
        <translation>Гучність %1</translation>
    </message>
</context>
<context>
    <name>Exporter</name>
    <message>
        <source>Save</source>
        <translation>Зберегти</translation>
    </message>
    <message>
        <source>Export Photos</source>
        <translation>Експортувати фотографії</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
</context>
<context>
    <name>ImageEngineApi</name>
    <message>
        <source>Deleting...</source>
        <translation>Вилучення...</translation>
    </message>
    <message>
        <source>Restoring...</source>
        <translation>Відновлення…</translation>
    </message>
    <message>
        <source>Classifying...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImgDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Вилучити</translation>
    </message>
    <message>
        <source>Are you sure you want to permanently delete this file?</source>
        <translation>Ви справді хочете остаточно вилучити цей файл?</translation>
    </message>
    <message>
        <source>You cannot restore it any longer</source>
        <translation>Надалі, ви не зможете його відновити</translation>
    </message>
    <message>
        <source>Are you sure you want to permanently delete %1 files?</source>
        <translation>Ви справді хочете остаточно вилучити %1 файлів?</translation>
    </message>
    <message>
        <source>You cannot restore them any longer</source>
        <translation>Надалі, ви не зможете їх відновити</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this file locally?</source>
        <translation>Ви справді хочете вилучити цей файл локально?</translation>
    </message>
    <message>
        <source>You can restore it in the trash</source>
        <translation>Ви зможете відновити його зі смітника</translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 files locally?</source>
        <translation>Ви справді хочете вилучити ці %1 файлів локально?</translation>
    </message>
    <message>
        <source>You can restore them in the trash</source>
        <translation>Ви зможете відновити їх зі смітника</translation>
    </message>
</context>
<context>
    <name>ImgInfoDialog</name>
    <message>
        <source>Basic info</source>
        <translation>Базові відомості</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Подробиці</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Дані щодо зображення</translation>
    </message>
</context>
<context>
    <name>ImportTimeLineView</name>
    <message>
        <source>Import</source>
        <translation>Імпортувати</translation>
    </message>
    <message>
        <source>1 photo</source>
        <translation>1 фотографія</translation>
    </message>
    <message>
        <source>1 video</source>
        <translation>1 відео</translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation>
            <numerusform>%n фотографія</numerusform>
            <numerusform>%1 фотографії</numerusform>
            <numerusform>%n фотографій</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation>
            <numerusform>%n відео</numerusform>
            <numerusform>%n відео</numerusform>
            <numerusform>%n відео</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items</source>
        <translation>
            <numerusform>%n запис</numerusform>
            <numerusform>%n записи</numerusform>
            <numerusform>%n записів</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ImportView</name>
    <message>
        <source>Import Photos and Videos</source>
        <translation>Імпортуйте фотографії та відео</translation>
    </message>
    <message>
        <source>Or drag them here</source>
        <translation>Або перетягніть їх сюди</translation>
    </message>
    <message>
        <source>All photos and videos</source>
        <translation>Усі фотографії і відео</translation>
    </message>
    <message>
        <source>No photos or videos found</source>
        <translation>Не знайдено жодної фотографії або відео</translation>
    </message>
</context>
<context>
    <name>LeftListView</name>
    <message>
        <source>Slide show</source>
        <translation>Показ слайдів</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Перейменувати</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Експортувати</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Вилучити</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Пристрій</translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation>Галерея</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>Альбоми</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Новий альбом</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Album is a fashion manager for viewing and organizing photos and videos.</source>
        <translation>«Альбом» — чудова програма для перегляду і упорядковування фотографій і відео.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Photos</source>
        <translation>Фотографії</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>На весь екран</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Довідка</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Показати у менеджері файлів</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Показ слайдів</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Копіювати</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Встановити зображенням тла</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Обертати за годинниковою стрілкою</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Обертати проти годинникової стрілки</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Назад</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Далі</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Додати до вибраних</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Вилучити з вибраних</translation>
    </message>
    <message>
        <source>Rename album</source>
        <translation>Перейменувати альбом</translation>
    </message>
    <message>
        <source>Album “%1” removed</source>
        <translation>Альбом «%1» вилучено</translation>
    </message>
    <message>
        <source>Successfully added to “%1”</source>
        <translation>Успішно додано до «%1»</translation>
    </message>
    <message>
        <source>Import successful</source>
        <translation>Успішне імпортування</translation>
    </message>
    <message>
        <source>Import failed</source>
        <translation>Імпортування зазнало&#xa0;невдачі</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Не вдалося експортувати</translation>
    </message>
    <message>
        <source>Export successful</source>
        <translation>Успішне експортування</translation>
    </message>
    <message>
        <source>All Photos</source>
        <translation>Усі фотографії</translation>
    </message>
    <message>
        <source>Timelines</source>
        <translation>Розклади</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>Альбоми</translation>
    </message>
    <message>
        <source>Exit fullscreen/slideshow</source>
        <translation>Вийти з повноекранного режиму або показу слайдів</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Показати клавіатурні скорочення</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Перегляд</translation>
    </message>
    <message>
        <source>Select all</source>
        <translation>Позначити все</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>Збільшити</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>Зменшити</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Новий альбом</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Сторінка вгору</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Сторінка вниз</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Параметри</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>Імпортування…</translation>
    </message>
    <message>
        <source>All photos and videos</source>
        <translation>Усі фотографії і відео</translation>
    </message>
    <message>
        <source>Import Photos and Videos</source>
        <translation>Імпортуйте фотографії та відео</translation>
    </message>
    <message>
        <source>No photos or videos found</source>
        <translation>Не знайдено жодної фотографії або відео</translation>
    </message>
    <message>
        <source>Export photos</source>
        <translation>Експортувати фотографії</translation>
    </message>
    <message>
        <source>Import photos/videos</source>
        <translation>Імпортувати фотографії/відео</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Вилучити</translation>
    </message>
    <message>
        <source>Photo/Video info</source>
        <translation>Дані щодо фотографій/відео</translation>
    </message>
    <message>
        <source>Import photos and videos</source>
        <translation>Імпортуйте фотографії та відео</translation>
    </message>
    <message>
        <source>Import folders</source>
        <translation>Імпортувати теки</translation>
    </message>
    <message>
        <source>Import interrupted</source>
        <translation>Імпортування перервано</translation>
    </message>
    <message>
        <source>Cannot add this path, please try another one</source>
        <translation>Не вдалося додати цей шлях. Будь ласка, спробуйте якийсь інший</translation>
    </message>
    <message>
        <source>The path already exists</source>
        <translation>Шлях вже існує</translation>
    </message>
    <message>
        <source>Failed to restore %1 files: file name too long</source>
        <translation>Не вдалося відновити %1 файлів: назва файла є надто довгою</translation>
    </message>
    <message>
        <source>Classifying...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Flash</source>
        <translation>Спалах</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Тип</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Розмір файла</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Розміри</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Дата створення</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Дата зміни</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Режим експозиції</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Програма експозиції</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Час експозиції</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Діафрагма</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Фокальна відстань</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Макс. апертура</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Режим вимірювання</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Баланс білого</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Компенсація спалаху</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Модель фотоапарата</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Модель об&apos;єктива</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Простір кольорів</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Мітка</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Назва</translation>
    </message>
</context>
<context>
    <name>NoResultWidget</name>
    <message>
        <source>No results</source>
        <translation>Немає результатів</translation>
    </message>
</context>
<context>
    <name>PathManager</name>
    <message>
        <source>System Disk</source>
        <translation>Системний диск</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Select</source>
        <translation>Вибрати</translation>
    </message>
    <message>
        <source>Unselect</source>
        <translation>Зняти вибір</translation>
    </message>
    <message>
        <source>%1/%2/%3</source>
        <translation>%1/%2/%3</translation>
    </message>
    <message>
        <source>Imported on</source>
        <translation>Імпортовано</translation>
    </message>
    <message>
        <source> %1-%2-%3 %4</source>
        <translation> %3-%2-%1 %4</translation>
    </message>
    <message>
        <source>Imported on </source>
        <translation>Імпортовано</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Позначити все</translation>
    </message>
    <message>
        <source>Unselect All</source>
        <translation>Зняти позначення з усього</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Відновити</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Вилучити</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Усе</translation>
    </message>
    <message>
        <source>Photos</source>
        <translation>Фотографії</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Відео</translation>
    </message>
    <message>
        <source>No results</source>
        <translation>Немає результатів</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Додати до вибраних</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Обертати проти годинникової стрілки</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Обертати за годинниковою стрілкою</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>Імпортування…</translation>
    </message>
    <message>
        <source>%1/%2 items imported</source>
        <translation>Імпортовано %1 з %2 записів</translation>
    </message>
    <message>
        <source>%1/%2 items deleted</source>
        <translation>Вилучено %1 з %2 записів</translation>
    </message>
    <message>
        <source>%1 items imported, %2 items failed</source>
        <translation>Імпортовано %1 записів, %2 записів не вдалося імпортувати</translation>
    </message>
    <message>
        <source>1 photo selected</source>
        <translation>Позначено 1 фотографію</translation>
    </message>
    <message>
        <source>1 video selected</source>
        <translation>Позначено 1 відео</translation>
    </message>
    <message>
        <source>The photo/video already exists</source>
        <translation>Така фотографія або відео вже існує</translation>
    </message>
    <message numerus="yes">
        <source>%n photos selected</source>
        <translation>
            <numerusform>Позначено %n фотографію</numerusform>
            <numerusform>Позначено %n фотографії</numerusform>
            <numerusform>Позначено %n фотографій</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos selected</source>
        <translation>
            <numerusform>Позначено %n відео</numerusform>
            <numerusform>Позначено %n відео</numerusform>
            <numerusform>Позначено %n відео</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items selected</source>
        <translation>
            <numerusform>Позначено %n запис</numerusform>
            <numerusform>Позначено %n записи</numerusform>
            <numerusform>Позначено %n записів</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 items imported, %2 items exist already</source>
        <translation>Імпортовано %1 записів, %2 записів вже існує</translation>
    </message>
    <message>
        <source>%1/%2 items classifyed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scenery</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Food</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Humans</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Animals</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scene</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Plants</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Items</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>No search results</source>
        <translation>Нічого не знайдено</translation>
    </message>
    <message>
        <source>Slide Show</source>
        <translation>Показ слайдів</translation>
    </message>
    <message>
        <source>Search results</source>
        <translation>Результати пошуку</translation>
    </message>
    <message>
        <source>1 photo found</source>
        <translation>Знайдено 1 фотографію</translation>
    </message>
    <message numerus="yes">
        <source>%n videos found</source>
        <translation>
            <numerusform>Знайдено %n відео</numerusform>
            <numerusform>Знайдено %n відео</numerusform>
            <numerusform>Знайдено %n відео</numerusform>
        </translation>
    </message>
    <message>
        <source>1 video found</source>
        <translation>Знайдено 1 відео</translation>
    </message>
    <message numerus="yes">
        <source>%n items found</source>
        <translation>
            <numerusform>Знайдено %n запис</numerusform>
            <numerusform>Знайдено %n записи</numerusform>
            <numerusform>Знайдено %n записів</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n photos found</source>
        <translation>
            <numerusform>Знайдено %n фотографію</numerusform>
            <numerusform>Знайдено %n фотографії</numerusform>
            <numerusform>Знайдено %n фотографій</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <source>1 photo</source>
        <translation>1 фотографія</translation>
    </message>
    <message>
        <source>1 video</source>
        <translation>1 відео</translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation>
            <numerusform>%n фотографія</numerusform>
            <numerusform>%n фотографії</numerusform>
            <numerusform>%n фотографій</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation>
            <numerusform>%n відео</numerusform>
            <numerusform>%n відео</numerusform>
            <numerusform>%n відео</numerusform>
        </translation>
    </message>
    <message>
        <source>Importing: %1</source>
        <translation>Імпортування: %1</translation>
    </message>
    <message>
        <source>Exporting: %1</source>
        <translation>Експортування: %1</translation>
    </message>
</context>
<context>
    <name>ThumbnailListView</name>
    <message>
        <source>View</source>
        <translation>Перегляд</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>На весь екран</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Експортувати</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Додати до вибраних</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Вилучити з вибраних</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Обертати за годинниковою стрілкою</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Обертати проти годинникової стрілки</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Показати у менеджері файлів</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Встановити зображенням тла</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Вилучити</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Показ слайдів</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Копіювати</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation>Дані щодо фотографії</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Додати до альбому</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Вилучити з альбому</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Відновити</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Новий альбом</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Надрукувати</translation>
    </message>
    <message>
        <source>Video info</source>
        <translation>Дані щодо відео</translation>
    </message>
    <message>
        <source>days</source>
        <translation>днів</translation>
    </message>
</context>
<context>
    <name>TimeLineView</name>
    <message>
        <source>1 photo</source>
        <translation>1 фотографія</translation>
    </message>
    <message>
        <source>1 video</source>
        <translation>1 відео</translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation>
            <numerusform>%n фотографія</numerusform>
            <numerusform>%1 фотографії</numerusform>
            <numerusform>%1 фотографій</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation>
            <numerusform>%n відео</numerusform>
            <numerusform>%n відео</numerusform>
            <numerusform>%n відео</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items</source>
        <translation>
            <numerusform>%n запис</numerusform>
            <numerusform>%n записи</numerusform>
            <numerusform>%n записів</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>VideoInfoDialog</name>
    <message>
        <source>Basic info</source>
        <translation>Базові відомості</translation>
    </message>
    <message>
        <source>Codec info</source>
        <translation>Дані щодо кодека</translation>
    </message>
    <message>
        <source>Audio info</source>
        <translation>Дані щодо звуку</translation>
    </message>
    <message>
        <source>Video CodecID</source>
        <translation>Ідентифікатор відеокодека</translation>
    </message>
    <message>
        <source>Video CodeRate</source>
        <translation>Швидкість відеоданих</translation>
    </message>
    <message>
        <source>FPS</source>
        <translation>Частота кадрів</translation>
    </message>
    <message>
        <source>Proportion</source>
        <translation>Пропорції</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Роздільність</translation>
    </message>
    <message>
        <source>Audio CodecID</source>
        <translation>Ідентифікатор аудіокодека</translation>
    </message>
    <message>
        <source>Audio CodeRate</source>
        <translation>Швидкість звукових даних</translation>
    </message>
    <message>
        <source>Audio digit</source>
        <translation>Цифровий звук</translation>
    </message>
    <message>
        <source>Channels</source>
        <translation>Канали</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Канал</translation>
    </message>
    <message>
        <source>Sampling</source>
        <translation>Дискретизація</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Дата зміни</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Тип</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Розмір файла</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Тривалість</translation>
    </message>
    <message>
        <source>Path</source>
        <translation>Шлях</translation>
    </message>
    <message>
        <source>Video info</source>
        <translation>Дані щодо відео</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Дата створення</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Назва</translation>
    </message>
</context>
</TS>
